/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sk extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "001", "svet" },
            { "002", "Afrika" },
            { "003", "Severn\u00e1 Amerika" },
            { "005", "Ju\u017en\u00e1 Amerika" },
            { "009", "Oce\u00e1nia" },
            { "011", "z\u00e1padn\u00e1 Afrika" },
            { "013", "Stredn\u00e1 Amerika" },
            { "014", "v\u00fdchodn\u00e1 Afrika" },
            { "015", "severn\u00e1 Afrika" },
            { "017", "stredn\u00e1 Afrika" },
            { "018", "ju\u017en\u00e9 \u00fazemia Afriky" },
            { "019", "Amerika" },
            { "021", "severn\u00e9 \u00fazemia Ameriky" },
            { "029", "Karibik" },
            { "030", "v\u00fdchodn\u00e1 \u00c1zia" },
            { "034", "ju\u017en\u00e1 \u00c1zia" },
            { "035", "juhov\u00fdchodn\u00e1 \u00c1zia" },
            { "039", "ju\u017en\u00e1 Eur\u00f3pa" },
            { "053", "Austral\u00e1zia" },
            { "054", "Melan\u00e9zia" },
            { "057", "oblas\u0165 Mikron\u00e9zie" },
            { "061", "Polyn\u00e9zia" },
            { "142", "\u00c1zia" },
            { "143", "stredn\u00e1 \u00c1zia" },
            { "145", "z\u00e1padn\u00e1 \u00c1zia" },
            { "150", "Eur\u00f3pa" },
            { "151", "v\u00fdchodn\u00e1 Eur\u00f3pa" },
            { "154", "severn\u00e1 Eur\u00f3pa" },
            { "155", "z\u00e1padn\u00e1 Eur\u00f3pa" },
            { "202", "subsaharsk\u00e1 Afrika" },
            { "419", "Latinsk\u00e1 Amerika" },
            { "AC", "Ascension" },
            { "AD", "Andorra" },
            { "AE", "Spojen\u00e9 arabsk\u00e9 emir\u00e1ty" },
            { "AF", "Afganistan" },
            { "AG", "Antigua a Barbuda" },
            { "AI", "Anguilla" },
            { "AL", "Alb\u00e1nsko" },
            { "AM", "Arm\u00e9nsko" },
            { "AO", "Angola" },
            { "AQ", "Antarkt\u00edda" },
            { "AR", "Argent\u00edna" },
            { "AS", "Americk\u00e1 Samoa" },
            { "AT", "Rak\u00fasko" },
            { "AU", "Austr\u00e1lia" },
            { "AW", "Aruba" },
            { "AX", "Alandy" },
            { "AZ", "Azerbajd\u017ean" },
            { "BA", "Bosna a Hercegovina" },
            { "BB", "Barbados" },
            { "BD", "Banglad\u00e9\u0161" },
            { "BE", "Belgicko" },
            { "BF", "Burkina Faso" },
            { "BG", "Bulharsko" },
            { "BH", "Bahrajn" },
            { "BI", "Burundi" },
            { "BJ", "Benin" },
            { "BL", "Sv\u00e4t\u00fd Bartolomej" },
            { "BM", "Bermudy" },
            { "BN", "Brunej" },
            { "BO", "Bol\u00edvia" },
            { "BQ", "Karibsk\u00e9 Holandsko" },
            { "BR", "Braz\u00edlia" },
            { "BS", "Bahamy" },
            { "BT", "Bhut\u00e1n" },
            { "BV", "Bouvetov ostrov" },
            { "BW", "Botswana" },
            { "BY", "Bielorusko" },
            { "BZ", "Belize" },
            { "CA", "Kanada" },
            { "CC", "Kokosov\u00e9 ostrovy" },
            { "CD", "Kon\u017esk\u00e1 demokratick\u00e1 republika" },
            { "CF", "Stredoafrick\u00e1 republika" },
            { "CG", "Kon\u017esk\u00e1 republika" },
            { "CH", "\u0160vaj\u010diarsko" },
            { "CI", "Pobre\u017eie Slonoviny" },
            { "CK", "Cookove ostrovy" },
            { "CL", "\u010cile" },
            { "CM", "Kamerun" },
            { "CN", "\u010c\u00edna" },
            { "CO", "Kolumbia" },
            { "CP", "Clipperton" },
            { "CR", "Kostarika" },
            { "CU", "Kuba" },
            { "CV", "Kapverdy" },
            { "CW", "Cura\u00e7ao" },
            { "CX", "Viano\u010dn\u00fd ostrov" },
            { "CY", "Cyprus" },
            { "CZ", "\u010cesko" },
            { "DE", "Nemecko" },
            { "DG", "Diego Garcia" },
            { "DJ", "D\u017eibutsko" },
            { "DK", "D\u00e1nsko" },
            { "DM", "Dominika" },
            { "DO", "Dominik\u00e1nska republika" },
            { "DZ", "Al\u017e\u00edrsko" },
            { "EA", "Ceuta a Melilla" },
            { "EC", "Ekv\u00e1dor" },
            { "EE", "Est\u00f3nsko" },
            { "EG", "Egypt" },
            { "EH", "Z\u00e1padn\u00e1 Sahara" },
            { "ER", "Eritrea" },
            { "ES", "\u0160panielsko" },
            { "ET", "Eti\u00f3pia" },
            { "EU", "Eur\u00f3pska \u00fania" },
            { "EZ", "euroz\u00f3na" },
            { "FI", "F\u00ednsko" },
            { "FJ", "Fid\u017ei" },
            { "FK", "Falklandy" },
            { "FM", "Mikron\u00e9zia" },
            { "FO", "Faersk\u00e9 ostrovy" },
            { "FR", "Franc\u00fazsko" },
            { "GA", "Gabon" },
            { "GB", "Spojen\u00e9 kr\u00e1\u013eovstvo" },
            { "GD", "Grenada" },
            { "GE", "Gruz\u00ednsko" },
            { "GF", "Franc\u00fazska Guyana" },
            { "GG", "Guernsey" },
            { "GH", "Ghana" },
            { "GI", "Gibralt\u00e1r" },
            { "GL", "Gr\u00f3nsko" },
            { "GM", "Gambia" },
            { "GN", "Guinea" },
            { "GP", "Guadeloupe" },
            { "GQ", "Rovn\u00edkov\u00e1 Guinea" },
            { "GR", "Gr\u00e9cko" },
            { "GS", "Ju\u017en\u00e1 Georgia a Ju\u017en\u00e9 Sandwichove ostrovy" },
            { "GT", "Guatemala" },
            { "GU", "Guam" },
            { "GW", "Guinea-Bissau" },
            { "GY", "Guyana" },
            { "HK", "Hongkong \u2013 OAO \u010c\u00edny" },
            { "HM", "Heardov ostrov a Macdonaldove ostrovy" },
            { "HN", "Honduras" },
            { "HR", "Chorv\u00e1tsko" },
            { "HT", "Haiti" },
            { "HU", "Ma\u010farsko" },
            { "IC", "Kan\u00e1rske ostrovy" },
            { "ID", "Indon\u00e9zia" },
            { "IE", "\u00cdrsko" },
            { "IL", "Izrael" },
            { "IM", "Ostrov Man" },
            { "IN", "India" },
            { "IO", "Britsk\u00e9 indickooce\u00e1nske \u00fazemie" },
            { "IQ", "Irak" },
            { "IR", "Ir\u00e1n" },
            { "IS", "Island" },
            { "IT", "Taliansko" },
            { "JE", "Jersey" },
            { "JM", "Jamajka" },
            { "JO", "Jord\u00e1nsko" },
            { "JP", "Japonsko" },
            { "KE", "Ke\u0148a" },
            { "KG", "Kirgizsko" },
            { "KH", "Kambod\u017ea" },
            { "KI", "Kiribati" },
            { "KM", "Komory" },
            { "KN", "Sv\u00e4t\u00fd Kri\u0161tof a Nevis" },
            { "KP", "Severn\u00e1 K\u00f3rea" },
            { "KR", "Ju\u017en\u00e1 K\u00f3rea" },
            { "KW", "Kuvajt" },
            { "KY", "Kajmanie ostrovy" },
            { "KZ", "Kazachstan" },
            { "LA", "Laos" },
            { "LB", "Libanon" },
            { "LC", "Sv\u00e4t\u00e1 Lucia" },
            { "LI", "Lichten\u0161tajnsko" },
            { "LK", "Sr\u00ed Lanka" },
            { "LR", "Lib\u00e9ria" },
            { "LS", "Lesotho" },
            { "LT", "Litva" },
            { "LU", "Luxembursko" },
            { "LV", "Loty\u0161sko" },
            { "LY", "L\u00edbya" },
            { "MA", "Maroko" },
            { "MC", "Monako" },
            { "MD", "Moldavsko" },
            { "ME", "\u010cierna Hora" },
            { "MF", "Sv\u00e4t\u00fd Martin (fr.)" },
            { "MG", "Madagaskar" },
            { "MH", "Marshallove ostrovy" },
            { "MK", "Severn\u00e9 Maced\u00f3nsko" },
            { "ML", "Mali" },
            { "MM", "Mjanmarsko" },
            { "MN", "Mongolsko" },
            { "MO", "Macao \u2013 OAO \u010c\u00edny" },
            { "MP", "Severn\u00e9 Mari\u00e1ny" },
            { "MQ", "Martinik" },
            { "MR", "Maurit\u00e1nia" },
            { "MS", "Montserrat" },
            { "MT", "Malta" },
            { "MU", "Maur\u00edcius" },
            { "MV", "Maldivy" },
            { "MW", "Malawi" },
            { "MX", "Mexiko" },
            { "MY", "Malajzia" },
            { "MZ", "Mozambik" },
            { "NA", "Nam\u00edbia" },
            { "NC", "Nov\u00e1 Kaled\u00f3nia" },
            { "NE", "Niger" },
            { "NF", "Norfolk" },
            { "NG", "Nig\u00e9ria" },
            { "NI", "Nikaragua" },
            { "NL", "Holandsko" },
            { "NO", "N\u00f3rsko" },
            { "NP", "Nep\u00e1l" },
            { "NR", "Nauru" },
            { "NU", "Niue" },
            { "NZ", "Nov\u00fd Z\u00e9land" },
            { "OM", "Om\u00e1n" },
            { "PA", "Panama" },
            { "PE", "Peru" },
            { "PF", "Franc\u00fazska Polyn\u00e9zia" },
            { "PG", "Papua-Nov\u00e1 Guinea" },
            { "PH", "Filip\u00edny" },
            { "PK", "Pakistan" },
            { "PL", "Po\u013esko" },
            { "PM", "Saint Pierre a Miquelon" },
            { "PN", "Pitcairnove ostrovy" },
            { "PR", "Portoriko" },
            { "PS", "Palest\u00ednske \u00fazemia" },
            { "PT", "Portugalsko" },
            { "PW", "Palau" },
            { "PY", "Paraguaj" },
            { "QA", "Katar" },
            { "QO", "ostatn\u00e9 Tichomorie" },
            { "RE", "R\u00e9union" },
            { "RO", "Rumunsko" },
            { "RS", "Srbsko" },
            { "RU", "Rusko" },
            { "RW", "Rwanda" },
            { "SA", "Saudsk\u00e1 Ar\u00e1bia" },
            { "SB", "\u0160alam\u00fanove ostrovy" },
            { "SC", "Seychely" },
            { "SD", "Sud\u00e1n" },
            { "SE", "\u0160v\u00e9dsko" },
            { "SG", "Singapur" },
            { "SH", "Sv\u00e4t\u00e1 Helena" },
            { "SI", "Slovinsko" },
            { "SJ", "Svalbard a Jan Mayen" },
            { "SK", "Slovensko" },
            { "SL", "Sierra Leone" },
            { "SM", "San Mar\u00edno" },
            { "SN", "Senegal" },
            { "SO", "Som\u00e1lsko" },
            { "SR", "Surinam" },
            { "SS", "Ju\u017en\u00fd Sud\u00e1n" },
            { "ST", "Sv\u00e4t\u00fd Tom\u00e1\u0161 a Princov ostrov" },
            { "SV", "Salv\u00e1dor" },
            { "SX", "Sv\u00e4t\u00fd Martin (hol.)" },
            { "SY", "S\u00fdria" },
            { "SZ", "Eswatini" },
            { "TA", "Tristan da Cunha" },
            { "TC", "Turks a Caicos" },
            { "TD", "\u010cad" },
            { "TF", "Franc\u00fazske ju\u017en\u00e9 a antarktick\u00e9 \u00fazemia" },
            { "TG", "Togo" },
            { "TH", "Thajsko" },
            { "TJ", "Tad\u017eikistan" },
            { "TK", "Tokelau" },
            { "TL", "V\u00fdchodn\u00fd Timor" },
            { "TM", "Turkm\u00e9nsko" },
            { "TN", "Tunisko" },
            { "TO", "Tonga" },
            { "TR", "Turecko" },
            { "TT", "Trinidad a Tobago" },
            { "TV", "Tuvalu" },
            { "TW", "Taiwan" },
            { "TZ", "Tanz\u00e1nia" },
            { "UA", "Ukrajina" },
            { "UG", "Uganda" },
            { "UM", "Men\u0161ie od\u013eahl\u00e9 ostrovy USA" },
            { "UN", "Organiz\u00e1cia Spojen\u00fdch n\u00e1rodov" },
            { "US", "Spojen\u00e9 \u0161t\u00e1ty" },
            { "UY", "Uruguaj" },
            { "UZ", "Uzbekistan" },
            { "VA", "Vatik\u00e1n" },
            { "VC", "Sv\u00e4t\u00fd Vincent a Grenad\u00edny" },
            { "VE", "Venezuela" },
            { "VG", "Britsk\u00e9 Panensk\u00e9 ostrovy" },
            { "VI", "Americk\u00e9 Panensk\u00e9 ostrovy" },
            { "VN", "Vietnam" },
            { "VU", "Vanuatu" },
            { "WF", "Wallis a Futuna" },
            { "WS", "Samoa" },
            { "XA", "falo\u0161n\u00e1 diakritika" },
            { "XB", "obr\u00e1tenie sprava do\u013eava" },
            { "XK", "Kosovo" },
            { "YE", "Jemen" },
            { "YT", "Mayotte" },
            { "ZA", "Ju\u017en\u00e1 Afrika" },
            { "ZM", "Zambia" },
            { "ZW", "Zimbabwe" },
            { "ZZ", "nezn\u00e1my regi\u00f3n" },
            { "aa", "afar\u010dina" },
            { "ab", "abch\u00e1z\u010dina" },
            { "ae", "avest\u010dina" },
            { "af", "afrik\u00e1n\u010dina" },
            { "ak", "akan\u010dina" },
            { "am", "amhar\u010dina" },
            { "an", "arag\u00f3n\u010dina" },
            { "ar", "arab\u010dina" },
            { "as", "\u00e1sam\u010dina" },
            { "av", "avar\u010dina" },
            { "ay", "aymar\u010dina" },
            { "az", "azerbajd\u017ean\u010dina" },
            { "ba", "ba\u0161kir\u010dina" },
            { "be", "bieloru\u0161tina" },
            { "bg", "bulhar\u010dina" },
            { "bi", "bislama" },
            { "bm", "bambar\u010dina" },
            { "bn", "beng\u00e1l\u010dina" },
            { "bo", "tibet\u010dina" },
            { "br", "bret\u00f3n\u010dina" },
            { "bs", "bosnia\u010dtina" },
            { "ca", "katal\u00e1n\u010dina" },
            { "ce", "\u010de\u010den\u010dina" },
            { "ch", "\u010damor\u010dina" },
            { "co", "korzi\u010dtina" },
            { "cr", "kr\u00ed" },
            { "cs", "\u010de\u0161tina" },
            { "cu", "cirkevn\u00e1 slovan\u010dina" },
            { "cv", "\u010duva\u0161tina" },
            { "cy", "wale\u0161tina" },
            { "da", "d\u00e1n\u010dina" },
            { "de", "nem\u010dina" },
            { "dv", "maldiv\u010dina" },
            { "dz", "dzongkha" },
            { "ee", "ewe\u0161tina" },
            { "el", "gr\u00e9\u010dtina" },
            { "en", "angli\u010dtina" },
            { "eo", "esperanto" },
            { "es", "\u0161paniel\u010dina" },
            { "et", "est\u00f3n\u010dina" },
            { "eu", "baski\u010dtina" },
            { "fa", "perz\u0161tina" },
            { "ff", "fulb\u010dina" },
            { "fi", "f\u00edn\u010dina" },
            { "fj", "fid\u017eij\u010dina" },
            { "fo", "faer\u010dina" },
            { "fr", "franc\u00faz\u0161tina" },
            { "fy", "z\u00e1padn\u00e1 fr\u00edz\u0161tina" },
            { "ga", "\u00edr\u010dina" },
            { "gd", "\u0161k\u00f3tska gael\u010dina" },
            { "gl", "gal\u00edcij\u010dina" },
            { "gn", "guaran\u00edj\u010dina" },
            { "gu", "gud\u017ear\u00e1t\u010dina" },
            { "gv", "man\u010dina" },
            { "ha", "hau\u0161tina" },
            { "he", "hebrej\u010dina" },
            { "hi", "hind\u010dina" },
            { "ho", "hiri motu" },
            { "hr", "chorv\u00e1t\u010dina" },
            { "ht", "haitsk\u00e1 kreol\u010dina" },
            { "hu", "ma\u010far\u010dina" },
            { "hy", "arm\u00e9n\u010dina" },
            { "hz", "herero" },
            { "ia", "interlingua" },
            { "id", "indon\u00e9z\u0161tina" },
            { "ie", "interlingue" },
            { "ig", "igbo\u0161tina" },
            { "ii", "s\u2019\u010dchuansk\u00e1 iov\u010dina" },
            { "ik", "inupik" },
            { "io", "ido" },
            { "is", "island\u010dina" },
            { "it", "talian\u010dina" },
            { "iu", "inuktitut" },
            { "ja", "japon\u010dina" },
            { "jv", "j\u00e1v\u010dina" },
            { "ka", "gruz\u00edn\u010dina" },
            { "kg", "kong\u010dina" },
            { "ki", "kikuj\u010dina" },
            { "kj", "kua\u0148ama" },
            { "kk", "kaza\u0161tina" },
            { "kl", "gr\u00f3n\u010dina" },
            { "km", "khm\u00e9r\u010dina" },
            { "kn", "kannad\u010dina" },
            { "ko", "k\u00f3rej\u010dina" },
            { "kr", "kanurij\u010dina" },
            { "ks", "ka\u0161m\u00edr\u010dina" },
            { "ku", "kurd\u010dina" },
            { "kv", "komij\u010dina" },
            { "kw", "korn\u010dina" },
            { "ky", "kirgiz\u0161tina" },
            { "la", "latin\u010dina" },
            { "lb", "luxembur\u010dina" },
            { "lg", "gand\u010dina" },
            { "li", "limbur\u010dina" },
            { "ln", "lingal\u010dina" },
            { "lo", "lao\u0161tina" },
            { "lt", "litov\u010dina" },
            { "lu", "lub\u010dina (katan\u017esk\u00e1)" },
            { "lv", "loty\u0161tina" },
            { "mg", "malga\u0161tina" },
            { "mh", "marshall\u010dina" },
            { "mi", "maorij\u010dina" },
            { "mk", "maced\u00f3n\u010dina" },
            { "ml", "malaj\u00e1lam\u010dina" },
            { "mn", "mongol\u010dina" },
            { "mr", "mar\u00e1th\u010dina" },
            { "ms", "malaj\u010dina" },
            { "mt", "malt\u010dina" },
            { "my", "barm\u010dina" },
            { "na", "nauru\u0161tina" },
            { "nb", "n\u00f3r\u010dina (bokmal)" },
            { "nd", "ndebel\u010dina (severn\u00e1)" },
            { "ne", "nep\u00e1l\u010dina" },
            { "ng", "ndonga" },
            { "nl", "holand\u010dina" },
            { "nn", "n\u00f3r\u010dina (nynorsk)" },
            { "no", "n\u00f3r\u010dina" },
            { "nr", "ndebel\u010dina (ju\u017en\u00e1)" },
            { "nv", "navaho" },
            { "ny", "\u0148and\u017ea" },
            { "oc", "okcit\u00e1n\u010dina" },
            { "oj", "od\u017eibva" },
            { "om", "orom\u010dina" },
            { "or", "ur\u00edj\u010dina" },
            { "os", "oset\u010dina" },
            { "pa", "pand\u017e\u00e1b\u010dina" },
            { "pi", "p\u00e1l\u00ed" },
            { "pl", "po\u013e\u0161tina" },
            { "ps", "pa\u0161t\u010dina" },
            { "pt", "portugal\u010dina" },
            { "qu", "ke\u010du\u00e1n\u010dina" },
            { "rm", "r\u00e9torom\u00e1n\u010dina" },
            { "rn", "rund\u010dina" },
            { "ro", "rumun\u010dina" },
            { "ru", "ru\u0161tina" },
            { "rw", "rwand\u010dina" },
            { "sa", "sanskrit" },
            { "sc", "sard\u00edn\u010dina" },
            { "sd", "sindh\u010dina" },
            { "se", "saam\u010dina (severn\u00e1)" },
            { "sg", "sango" },
            { "sh", "srbochorv\u00e1t\u010dina" },
            { "si", "sinhal\u010dina" },
            { "sk", "sloven\u010dina" },
            { "sl", "slovin\u010dina" },
            { "sm", "samoj\u010dina" },
            { "sn", "\u0161on\u010dina" },
            { "so", "som\u00e1l\u010dina" },
            { "sq", "alb\u00e1n\u010dina" },
            { "sr", "srb\u010dina" },
            { "ss", "svazij\u010dina" },
            { "st", "soth\u010dina (ju\u017en\u00e1)" },
            { "su", "sund\u010dina" },
            { "sv", "\u0161v\u00e9d\u010dina" },
            { "sw", "swahil\u010dina" },
            { "ta", "tamil\u010dina" },
            { "te", "telug\u010dina" },
            { "tg", "tad\u017ei\u010dtina" },
            { "th", "thaj\u010dina" },
            { "ti", "tigri\u0148a" },
            { "tk", "turkm\u00e9n\u010dina" },
            { "tl", "tagal\u010dina" },
            { "tn", "tswan\u010dina" },
            { "to", "tong\u010dina" },
            { "tr", "ture\u010dtina" },
            { "ts", "tsong\u010dina" },
            { "tt", "tat\u00e1r\u010dina" },
            { "tw", "twi" },
            { "ty", "tahit\u010dina" },
            { "ug", "ujgur\u010dina" },
            { "uk", "ukrajin\u010dina" },
            { "ur", "urd\u010dina" },
            { "uz", "uzbe\u010dtina" },
            { "ve", "vend\u010dina" },
            { "vi", "vietnam\u010dina" },
            { "vo", "volap\u00fck" },
            { "wa", "val\u00f3n\u010dina" },
            { "wo", "wolof\u010dina" },
            { "xh", "xho\u0161tina" },
            { "yi", "jidi\u0161" },
            { "yo", "jorub\u010dina" },
            { "za", "\u010duang\u010dina" },
            { "zh", "\u010d\u00edn\u0161tina" },
            { "zu", "zulu\u0161tina" },
            { "ace", "aceh\u010dina" },
            { "ach", "a\u010doli" },
            { "ada", "adangme" },
            { "ady", "adygej\u010dina" },
            { "afh", "afrihili" },
            { "agq", "aghem" },
            { "ain", "ain\u010dina" },
            { "akk", "akkad\u010dina" },
            { "ale", "aleut\u010dina" },
            { "alt", "ju\u017en\u00e1 altaj\u010dina" },
            { "ang", "star\u00e1 angli\u010dtina" },
            { "anp", "angika" },
            { "arc", "aramej\u010dina" },
            { "arn", "mapudungun" },
            { "arp", "arapa\u017e\u0161tina" },
            { "ars", "arab\u010dina (nad\u017edsk\u00e1)" },
            { "arw", "arawa\u010dtina" },
            { "asa", "asu" },
            { "ast", "ast\u00far\u010dina" },
            { "awa", "awadhi" },
            { "bal", "bal\u00fa\u010dtina" },
            { "ban", "balij\u010dina" },
            { "bas", "basa" },
            { "bax", "bamun" },
            { "bbj", "ghomala" },
            { "bej", "bed\u017ea" },
            { "bem", "bemba" },
            { "bez", "bena" },
            { "bfd", "bafut" },
            { "bgn", "z\u00e1padn\u00e1 bal\u00fa\u010dtina" },
            { "bho", "bh\u00f3d\u017epur\u010dina" },
            { "bik", "bikol\u010dina" },
            { "bin", "bini" },
            { "bkm", "kom" },
            { "bla", "siksika" },
            { "bra", "brad\u017e\u010dina" },
            { "brx", "bodo" },
            { "bss", "akoose" },
            { "bua", "buriat\u010dina" },
            { "bug", "bugi\u0161tina" },
            { "bum", "bulu" },
            { "byn", "blin" },
            { "byv", "medumba" },
            { "cad", "kaddo" },
            { "car", "karib\u010dina" },
            { "cay", "kajug\u010dina" },
            { "cch", "atsam" },
            { "ccp", "\u010dakma" },
            { "ceb", "cebu\u00e1n\u010dina" },
            { "cgg", "kiga" },
            { "chb", "\u010dib\u010da" },
            { "chg", "\u010dagataj\u010dina" },
            { "chk", "chuuk" },
            { "chm", "marij\u010dina" },
            { "chn", "\u010dinuck\u00fd \u017earg\u00f3n" },
            { "cho", "\u010dokt\u010dina" },
            { "chp", "\u010dipevaj\u010dina" },
            { "chr", "\u010derok\u00ed" },
            { "chy", "\u010dejen\u010dina" },
            { "ckb", "kurd\u010dina (sor\u00e1n\u00ed)" },
            { "cop", "kopt\u010dina" },
            { "crh", "krymsk\u00e1 tat\u00e1r\u010dina" },
            { "crs", "seychelsk\u00e1 kreol\u010dina" },
            { "csb", "ka\u0161ub\u010dina" },
            { "dak", "dakot\u010dina" },
            { "dar", "dargin\u010dina" },
            { "dav", "taita" },
            { "del", "delawar\u010dina" },
            { "den", "slav\u00e9" },
            { "dgr", "dogrib\u010dina" },
            { "din", "dink\u010dina" },
            { "dje", "zarma" },
            { "doi", "d\u00f3gr\u00ed" },
            { "dsb", "dolnolu\u017eick\u00e1 srb\u010dina" },
            { "dua", "duala" },
            { "dum", "stredn\u00e1 holand\u010dina" },
            { "dyo", "jola-fonyi" },
            { "dyu", "\u010fula" },
            { "dzg", "dazaga" },
            { "ebu", "embu" },
            { "efi", "efik" },
            { "egy", "staroegypt\u010dina" },
            { "eka", "ekad\u017euk" },
            { "elx", "elam\u010dina" },
            { "enm", "stredn\u00e1 angli\u010dtina" },
            { "ewo", "ewondo" },
            { "fan", "fang\u010dina" },
            { "fat", "fanti" },
            { "fil", "filip\u00edn\u010dina" },
            { "fon", "fon\u010dina" },
            { "frc", "franc\u00faz\u0161tina (Cajun)" },
            { "frm", "stredn\u00e1 franc\u00faz\u0161tina" },
            { "fro", "star\u00e1 franc\u00faz\u0161tina" },
            { "frr", "severn\u00e1 fr\u00edz\u0161tina" },
            { "frs", "v\u00fdchodofr\u00edz\u0161tina" },
            { "fur", "friul\u010dina" },
            { "gaa", "ga" },
            { "gag", "gagauz\u0161tina" },
            { "gay", "gayo" },
            { "gba", "gbaja" },
            { "gez", "eti\u00f3p\u010dina" },
            { "gil", "kiribat\u010dina" },
            { "gmh", "stredn\u00e1 horn\u00e1 nem\u010dina" },
            { "goh", "star\u00e1 horn\u00e1 nem\u010dina" },
            { "gon", "g\u00f3nd\u010dina" },
            { "gor", "gorontalo" },
            { "got", "g\u00f3t\u010dina" },
            { "grb", "grebo" },
            { "grc", "starogr\u00e9\u010dtina" },
            { "gsw", "nem\u010dina (\u0161vaj\u010diarska)" },
            { "guz", "gusii" },
            { "gwi", "ku\u010din\u010dina" },
            { "hai", "haida" },
            { "haw", "havaj\u010dina" },
            { "hil", "hiligajnon\u010dina" },
            { "hit", "chetit\u010dina" },
            { "hmn", "hmong\u010dina" },
            { "hsb", "hornolu\u017eick\u00e1 srb\u010dina" },
            { "hup", "hup\u010dina" },
            { "iba", "iban\u010dina" },
            { "ibb", "ibibio" },
            { "ilo", "ilok\u00e1n\u010dina" },
            { "inh", "ingu\u0161tina" },
            { "jbo", "lojban" },
            { "jgo", "ngomba" },
            { "jmc", "ma\u0161ame" },
            { "jpr", "\u017eidovsk\u00e1 perz\u0161tina" },
            { "jrb", "\u017eidovsk\u00e1 arab\u010dina" },
            { "kaa", "karakalpa\u010dtina" },
            { "kab", "kabyl\u010dina" },
            { "kac", "ka\u010djin\u010dina" },
            { "kaj", "jju" },
            { "kam", "kamba" },
            { "kaw", "kawi" },
            { "kbd", "kabard\u010dina" },
            { "kbl", "kanembu" },
            { "kcg", "tyap" },
            { "kde", "makonde" },
            { "kea", "kapverd\u010dina" },
            { "kfo", "koro" },
            { "kha", "khasij\u010dina" },
            { "kho", "chotan\u010dina" },
            { "khq", "z\u00e1padn\u00e1 songhaj\u010dina" },
            { "kkj", "kako" },
            { "kln", "kalend\u017ein" },
            { "kmb", "kimbundu" },
            { "koi", "komi-permia\u010dtina" },
            { "kok", "konk\u00e1n\u010dina" },
            { "kos", "kusaie" },
            { "kpe", "kpelle" },
            { "krc", "kara\u010dajevsko-balkar\u010dina" },
            { "krl", "karel\u010dina" },
            { "kru", "kuruch\u010dina" },
            { "ksb", "\u0161ambala" },
            { "ksf", "bafia" },
            { "ksh", "kol\u00edn\u010dina" },
            { "kum", "kumy\u010dtina" },
            { "kut", "kutenaj\u010dina" },
            { "lad", "\u017eidovsk\u00e1 \u0161paniel\u010dina" },
            { "lag", "langi" },
            { "lah", "lahand\u010dina" },
            { "lam", "lamba" },
            { "lez", "lezgin\u010dina" },
            { "lkt", "lakot\u010dina" },
            { "lol", "mongo" },
            { "lou", "kreol\u010dina (Louisiana)" },
            { "loz", "lozi" },
            { "lrc", "severn\u00e9 luri" },
            { "lua", "lub\u010dina (lulu\u00e1nska)" },
            { "lui", "luise\u0148o" },
            { "lun", "lunda" },
            { "luo", "luo" },
            { "lus", "mizor\u00e1m\u010dina" },
            { "luy", "luhja" },
            { "mad", "madur\u010dina" },
            { "maf", "mafa" },
            { "mag", "magadh\u010dina" },
            { "mai", "maithil\u010dina" },
            { "mak", "makasar\u010dina" },
            { "man", "mandingo" },
            { "mas", "masaj\u010dina" },
            { "mde", "maba" },
            { "mdf", "mok\u0161ian\u010dina" },
            { "mdr", "mandar\u010dina" },
            { "men", "mendej\u010dina" },
            { "mer", "meru" },
            { "mfe", "maur\u00edcijsk\u00e1 kreol\u010dina" },
            { "mga", "stredn\u00e1 \u00edr\u010dina" },
            { "mgh", "makua-meetto" },
            { "mgo", "meta\u2019" },
            { "mic", "mikmak\u010dina" },
            { "min", "minangkabau\u010dina" },
            { "mnc", "mand\u017eu\u0161tina" },
            { "mni", "man\u00edpur\u010dina" },
            { "moh", "mohawk\u010dina" },
            { "mos", "mossi" },
            { "mua", "mundang" },
            { "mul", "viacer\u00e9 jazyky" },
            { "mus", "kr\u00edk\u010dina" },
            { "mwl", "mirand\u010dina" },
            { "mwr", "marwari" },
            { "mye", "myene" },
            { "myv", "erzjan\u010dina" },
            { "mzn", "m\u00e1zandar\u00e1n\u010dina" },
            { "nap", "neapol\u010dina" },
            { "naq", "nama" },
            { "nds", "doln\u00e1 nem\u010dina" },
            { "new", "nev\u00e1r\u010dina" },
            { "nia", "nias\u00e1n\u010dina" },
            { "niu", "niue\u0161tina" },
            { "nmg", "kwasio" },
            { "nnh", "ngiemboon" },
            { "nog", "nogaj\u010dina" },
            { "non", "star\u00e1 n\u00f3r\u010dina" },
            { "nqo", "n\u2019ko" },
            { "nso", "soth\u010dina (severn\u00e1)" },
            { "nus", "nuer" },
            { "nwc", "klasick\u00e1 nev\u00e1r\u010dina" },
            { "nym", "\u0148amwezi" },
            { "nyn", "\u0148ankole" },
            { "nyo", "\u0148oro" },
            { "nzi", "nzima" },
            { "osa", "osed\u017e\u0161tina" },
            { "ota", "osmansk\u00e1 ture\u010dtina" },
            { "pag", "pangasinan\u010dina" },
            { "pal", "pahlav\u00ed" },
            { "pam", "kapampangan\u010dina" },
            { "pap", "papiamento" },
            { "pau", "palau\u010dina" },
            { "pcm", "nigerijsk\u00fd pid\u017ein" },
            { "peo", "star\u00e1 perz\u0161tina" },
            { "phn", "feni\u010dtina" },
            { "pon", "pohnpei\u0161tina" },
            { "prg", "pru\u0161tina" },
            { "pro", "star\u00e1 okcit\u00e1n\u010dina" },
            { "quc", "quich\u00e9" },
            { "raj", "rad\u017eastan\u010dina" },
            { "rap", "rapanuj\u010dina" },
            { "rar", "rarotongsk\u00e1 maorij\u010dina" },
            { "rof", "rombo" },
            { "rom", "r\u00f3m\u010dina" },
            { "rup", "arumun\u010dina" },
            { "rwk", "rwa" },
            { "sad", "sandawe\u0161tina" },
            { "sah", "jakut\u010dina" },
            { "sam", "samarit\u00e1nska aramej\u010dina" },
            { "saq", "samburu" },
            { "sas", "sasa\u010dtina" },
            { "sat", "santal\u010dina" },
            { "sba", "ngambay" },
            { "sbp", "sangu" },
            { "scn", "sic\u00edl\u010dina" },
            { "sco", "\u0161k\u00f3t\u010dina" },
            { "sdh", "ju\u017en\u00e1 kurd\u010dina" },
            { "see", "senek\u010dina" },
            { "seh", "sena" },
            { "sel", "selkup\u010dina" },
            { "ses", "koyraboro senni" },
            { "sga", "star\u00e1 \u00edr\u010dina" },
            { "shi", "tachelhit" },
            { "shn", "\u0161an\u010dina" },
            { "shu", "\u010dadsk\u00e1 arab\u010dina" },
            { "sid", "sidamo" },
            { "sma", "saam\u010dina (ju\u017en\u00e1)" },
            { "smj", "saam\u010dina (lulsk\u00e1)" },
            { "smn", "saam\u010dina (inarijsk\u00e1)" },
            { "sms", "saam\u010dina (skoltsk\u00e1)" },
            { "snk", "soninke" },
            { "sog", "sogdij\u010dina" },
            { "srn", "surinam\u010dina" },
            { "srr", "serer\u010dina" },
            { "ssy", "saho" },
            { "suk", "sukuma" },
            { "sus", "susu" },
            { "sux", "sumer\u010dina" },
            { "swb", "komor\u010dina" },
            { "syc", "s\u00fdr\u010dina (klasick\u00e1)" },
            { "syr", "s\u00fdr\u010dina" },
            { "tem", "temne" },
            { "teo", "teso" },
            { "ter", "ter\u00eana" },
            { "tet", "tetum\u010dina" },
            { "tig", "tigrej\u010dina" },
            { "tiv", "tiv" },
            { "tkl", "tokelau\u0161tina" },
            { "tlh", "kling\u00f3n\u010dina" },
            { "tli", "tlingit\u010dina" },
            { "tmh", "tuareg\u010dina" },
            { "tog", "\u0148asa tonga" },
            { "tpi", "novoguinejsk\u00fd pid\u017ein" },
            { "trv", "taroko" },
            { "tsi", "cim\u0161jan\u010dina" },
            { "tum", "tumbuka" },
            { "tvl", "tuval\u010dina" },
            { "twq", "tasawaq" },
            { "tyv", "tuvian\u010dina" },
            { "tzm", "tuareg\u010dina (stredomarock\u00e1)" },
            { "udm", "udmurt\u010dina" },
            { "uga", "ugarit\u010dina" },
            { "umb", "umbundu" },
            { "und", "nezn\u00e1my jazyk" },
            { "vai", "vai" },
            { "vot", "vod\u010dina" },
            { "vun", "vunjo" },
            { "wae", "walser\u010dina" },
            { "wal", "walam\u010dina" },
            { "war", "waray" },
            { "was", "washo" },
            { "wbp", "warlpiri" },
            { "xal", "kalmy\u010dtina" },
            { "xog", "soga" },
            { "yao", "jao" },
            { "yap", "jap\u010dina" },
            { "yav", "jangben" },
            { "ybb", "yemba" },
            { "yue", "kanton\u010dina" },
            { "zap", "zapot\u00e9\u010dtina" },
            { "zbl", "syst\u00e9m Bliss" },
            { "zen", "zenaga" },
            { "zgh", "tuareg\u010dina (marock\u00e1 \u0161tandardn\u00e1)" },
            { "zun", "zuni\u0161tina" },
            { "zxx", "bez jazykov\u00e9ho obsahu" },
            { "zza", "zaza" },
            { "Arab", "arabsk\u00e9" },
            { "Aran", "nastaliq" },
            { "Armn", "arm\u00e9nske" },
            { "Bali", "balijsk\u00fd" },
            { "Beng", "beng\u00e1lske" },
            { "Bopo", "bopomofo" },
            { "Brai", "braillovo" },
            { "Cyrl", "cyrilika" },
            { "Deva", "d\u00e9van\u00e1gar\u00ed" },
            { "Egyp", "egyptsk\u00e9 hieroglyfy" },
            { "Ethi", "eti\u00f3pske" },
            { "Geor", "gruz\u00ednske" },
            { "Glag", "hlaholika" },
            { "Goth", "gotick\u00fd" },
            { "Grek", "gr\u00e9cke" },
            { "Gujr", "gud\u017ear\u00e1t\u00ed" },
            { "Guru", "gurmukhi" },
            { "Hanb", "\u010d\u00ednske a bopomofo" },
            { "Hang", "hangul" },
            { "Hani", "\u010d\u00ednske" },
            { "Hans", "zjednodu\u0161en\u00e9" },
            { "Hant", "tradi\u010dn\u00e9" },
            { "Hebr", "hebrejsk\u00e9" },
            { "Hira", "hiragana" },
            { "Hrkt", "kana" },
            { "Jamo", "jamo" },
            { "Jpan", "japonsk\u00e9" },
            { "Kana", "katakana" },
            { "Khmr", "khm\u00e9rske" },
            { "Knda", "kannadsk\u00e9" },
            { "Kore", "k\u00f3rejsk\u00e9" },
            { "Laoo", "laosk\u00e9" },
            { "Latn", "latinka" },
            { "Lina", "line\u00e1rna A" },
            { "Linb", "line\u00e1rna B" },
            { "Maya", "maysk\u00e9 hieroglyfy" },
            { "Mlym", "malaj\u00e1lamske" },
            { "Mong", "mongolsk\u00e9" },
            { "Mtei", "mejtej majek (manipursk\u00e9)" },
            { "Mymr", "barmsk\u00e9" },
            { "Olck", "sant\u00e1lske (ol chiki)" },
            { "Orya", "ur\u00edjske" },
            { "Osma", "osmansk\u00fd" },
            { "Qaag", "zawgyi" },
            { "Runr", "Runov\u00e9 p\u00edsmo" },
            { "Sinh", "sinh\u00e1lske" },
            { "Taml", "tamilsk\u00e9" },
            { "Telu", "telugsk\u00e9" },
            { "Thaa", "t\u00e1na" },
            { "Thai", "thajsk\u00e9" },
            { "Tibt", "tibetsk\u00e9" },
            { "Zmth", "matematick\u00fd z\u00e1pis" },
            { "Zsye", "emod\u017ei" },
            { "Zsym", "symboly" },
            { "Zxxx", "bez z\u00e1pisu" },
            { "Zyyy", "v\u0161eobecn\u00e9" },
            { "Zzzz", "nezn\u00e1me p\u00edsmo" },
            { "root", "kore\u0148" },
            { "de_AT", "nem\u010dina (rak\u00faska)" },
            { "de_CH", "nem\u010dina (\u0161vaj\u010diarska spisovn\u00e1)" },
            { "en_AU", "angli\u010dtina (austr\u00e1lska)" },
            { "en_CA", "angli\u010dtina (kanadsk\u00e1)" },
            { "en_GB", "angli\u010dtina (britsk\u00e1)" },
            { "en_US", "angli\u010dtina (americk\u00e1)" },
            { "es_ES", "\u0161paniel\u010dina (eur\u00f3pska)" },
            { "es_MX", "\u0161paniel\u010dina (mexick\u00e1)" },
            { "fa_AF", "dar\u00edj\u010dina" },
            { "fr_CA", "franc\u00faz\u0161tina (kanadsk\u00e1)" },
            { "fr_CH", "franc\u00faz\u0161tina (\u0161vaj\u010diarska)" },
            { "nl_BE", "fl\u00e1m\u010dina" },
            { "pt_BR", "portugal\u010dina (braz\u00edlska)" },
            { "pt_PT", "portugal\u010dina (eur\u00f3pska)" },
            { "ro_MD", "moldav\u010dina" },
            { "sw_CD", "svahil\u010dina (kon\u017esk\u00e1)" },
            { "ar_001", "arab\u010dina (modern\u00e1 \u0161tandardn\u00e1)" },
            { "es_419", "\u0161paniel\u010dina (latinskoamerick\u00e1)" },
            { "key.ca", "kalend\u00e1r" },
            { "key.cf", "form\u00e1t meny" },
            { "key.co", "zoradenie" },
            { "key.cu", "mena" },
            { "key.hc", "hodinov\u00fd cyklus (12 vs 24)" },
            { "key.lb", "\u0161t\u00fdl koncov riadka" },
            { "key.ms", "mern\u00e1 s\u00fastava" },
            { "key.nu", "\u010d\u00edsla" },
            { "key.tz", "\u010dasov\u00e9 p\u00e1smo" },
            { "key.va", "variant miestneho nastavenia" },
            { "nds_NL", "doln\u00e1 sa\u0161tina" },
            { "zh_Hans", "\u010d\u00edn\u0161tina (zjednodu\u0161en\u00e1)" },
            { "zh_Hant", "\u010d\u00edn\u0161tina (tradi\u010dn\u00e1)" },
            { "%%SCOTLAND", "\u0161k\u00f3tska \u0161tandardn\u00e1 angli\u010dtina" },
            { "type.ca.roc", "\u010d\u00ednsky republik\u00e1nsky kalend\u00e1r" },
            { "type.co.eor", "eur\u00f3pske zoradenie" },
            { "type.hc.h11", "12-hodinov\u00fd cyklus (0 \u2013 11)" },
            { "type.hc.h12", "12-hodinov\u00fd cyklus (1 \u2013 12)" },
            { "type.hc.h23", "24-hodinov\u00fd cyklus (0 \u2013 23)" },
            { "type.hc.h24", "24-hodinov\u00fd cyklus (1 \u2013 24)" },
            { "type.m0.bgn", "americk\u00e1 transliter\u00e1cia BGN" },
            { "type.nu.arab", "arabsko-indick\u00e9 \u010d\u00edslice" },
            { "type.nu.armn", "arm\u00e9nske \u010d\u00edslice" },
            { "type.nu.beng", "beng\u00e1lske \u010d\u00edslice" },
            { "type.nu.deva", "\u010d\u00edslice d\u00e9van\u00e1gar\u00ed" },
            { "type.nu.ethi", "eti\u00f3pske \u010d\u00edslice" },
            { "type.nu.geor", "gruz\u00ednske \u010d\u00edslice" },
            { "type.nu.grek", "gr\u00e9cke \u010d\u00edslice" },
            { "type.nu.gujr", "gud\u017ear\u00e1tske \u010d\u00edslice" },
            { "type.nu.guru", "\u010d\u00edslice gurumukh\u00ed" },
            { "type.nu.hans", "\u010d\u00edslice zjednodu\u0161enej \u010d\u00edn\u0161tiny" },
            { "type.nu.hant", "\u010d\u00edslice tradi\u010dnej \u010d\u00edn\u0161tiny" },
            { "type.nu.hebr", "hebrejsk\u00e9 \u010d\u00edslice" },
            { "type.nu.jpan", "japonsk\u00e9 \u010d\u00edslice" },
            { "type.nu.khmr", "khm\u00e9rske \u010d\u00edslice" },
            { "type.nu.knda", "kannadsk\u00e9 \u010d\u00edslice" },
            { "type.nu.laoo", "laosk\u00e9 \u010d\u00edslice" },
            { "type.nu.latn", "arabsk\u00e9 \u010d\u00edslice" },
            { "type.nu.mlym", "malaj\u00e1lamske \u010d\u00edslice" },
            { "type.nu.mong", "Mongolsk\u00e9 \u010d\u00edslice" },
            { "type.nu.mymr", "barmsk\u00e9 \u010d\u00edslice" },
            { "type.nu.orya", "ur\u00edjske \u010d\u00edslice" },
            { "type.nu.taml", "\u010d\u00edslice tradi\u010dnej tamil\u010diny" },
            { "type.nu.telu", "telugsk\u00e9 \u010d\u00edslice" },
            { "type.nu.thai", "thajsk\u00e9 \u010d\u00edslice" },
            { "type.nu.tibt", "tibetsk\u00e9 \u010d\u00edslice" },
            { "type.nu.vaii", "Vaisk\u00e9 \u010d\u00edslice" },
            { "type.ca.dangi", "k\u00f3rejsk\u00fd kalend\u00e1r" },
            { "type.co.ducet", "predvolen\u00e9 zoradenie unicode" },
            { "type.lb.loose", "vo\u013en\u00fd \u0161t\u00fdl koncov riadka" },
            { "type.nu.roman", "r\u00edmske \u010d\u00edslice" },
            { "type.ca.coptic", "Koptick\u00fd kalend\u00e1r" },
            { "type.ca.hebrew", "\u017eidovsk\u00fd kalend\u00e1r" },
            { "type.ca.indian", "Indick\u00fd n\u00e1rodn\u00fd kalend\u00e1r" },
            { "type.co.compat", "predch\u00e1dzaj\u00face zoradenie, kompatibilita" },
            { "type.co.pinyin", "Triedenie pinyin" },
            { "type.co.search", "v\u0161eobecn\u00e9 vyh\u013ead\u00e1vanie" },
            { "type.co.stroke", "Tiedenie pod\u013ea \u0165ahov" },
            { "type.co.unihan", "Usporiadanie pod\u013ea znakov radik\u00e1l" },
            { "type.d0.fwidth", "cel\u00e1 \u0161\u00edrka" },
            { "type.d0.hwidth", "polovi\u010dn\u00e1 \u0161\u00edrka" },
            { "type.lb.normal", "be\u017en\u00fd \u0161t\u00fdl koncov riadka" },
            { "type.lb.strict", "presn\u00fd \u0161t\u00fdl koncov riadka" },
            { "type.m0.ungegn", "medzin\u00e1rodn\u00e1 transliter\u00e1cia GEGN" },
            { "type.ms.metric", "metrick\u00e1 s\u00fastava" },
            { "type.nu.native", "Nat\u00edvne \u010d\u00edslice" },
            { "type.ca.chinese", "\u010d\u00ednsky kalend\u00e1r" },
            { "type.ca.islamic", "islamsk\u00fd kalend\u00e1r" },
            { "type.ca.iso8601", "kalend\u00e1r ISO 8601" },
            { "type.ca.persian", "perzsk\u00fd kalend\u00e1r" },
            { "type.cf.account", "\u00fa\u010dtovn\u00fd form\u00e1t meny" },
            { "type.co.big5han", "Tradi\u010dn\u00fd \u010d\u00ednsky Big5" },
            { "type.d0.npinyin", "\u010c\u00edslice" },
            { "type.nu.arabext", "roz\u0161\u00edren\u00e9 arabsko-indick\u00e9 \u010d\u00edslice" },
            { "type.nu.armnlow", "mal\u00e9 arm\u00e9nske \u010d\u00edslice" },
            { "type.nu.finance", "Finan\u010dn\u00edcky z\u00e1pis \u010d\u00edsiel" },
            { "type.nu.greklow", "mal\u00e9 gr\u00e9cke \u010d\u00edslice" },
            { "type.nu.hanidec", "\u010d\u00ednske desiatkov\u00e9 \u010d\u00edslice" },
            { "type.nu.hansfin", "finan\u010dn\u00e9 \u010d\u00edslice zjednodu\u0161enej \u010d\u00edn\u0161tiny" },
            { "type.nu.hantfin", "finan\u010dn\u00e9 \u010d\u00edslice tradi\u010dnej \u010d\u00edn\u0161tiny" },
            { "type.nu.jpanfin", "japonsk\u00e9 finan\u010dn\u00e9 \u010d\u00edslice" },
            { "type.nu.tamldec", "tamilsk\u00e9 \u010d\u00edslice" },
            { "type.ca.buddhist", "buddhistick\u00fd kalend\u00e1r" },
            { "type.ca.ethiopic", "eti\u00f3psky kalend\u00e1r" },
            { "type.ca.japanese", "japonsk\u00fd kalend\u00e1r" },
            { "type.cf.standard", "\u0161tandardn\u00fd form\u00e1t meny" },
            { "type.co.phonetic", "Fonetick\u00e9 radenie" },
            { "type.co.reformed", "Reformovan\u00e9 usporiadanie" },
            { "type.co.searchjl", "H\u013eada\u0165 pod\u013ea po\u010diato\u010dnej spoluhl\u00e1sky p\u00edsma Hangul" },
            { "type.co.standard", "\u0161tandardn\u00e9 zoradenie" },
            { "type.ms.uksystem", "britsk\u00e1 mern\u00e1 s\u00fastava" },
            { "type.ms.ussystem", "americk\u00e1 mern\u00e1 s\u00fastava" },
            { "type.nu.fullwide", "\u010d\u00edslice s celou \u0161\u00edrkou" },
            { "type.nu.romanlow", "mal\u00e9 r\u00edmske \u010d\u00edslice" },
            { "type.ca.gregorian", "gregori\u00e1nsky kalend\u00e1r" },
            { "type.co.gb2312han", "Zjednodu\u0161en\u00fd \u010d\u00ednsky GB2312" },
            { "type.co.phonebook", "Lexikografick\u00e9 triedenie" },
            { "type.co.dictionary", "Usporiadanie slovn\u00edka" },
            { "type.co.traditional", "Tradi\u010dn\u00e9" },
            { "type.nu.traditional", "Tradi\u010dn\u00e9 \u010d\u00edslovky" },
            { "type.ca.islamic-civil", "Islamsk\u00fd ob\u010diansky kalend\u00e1r" },
            { "type.ca.islamic-umalqura", "islamsk\u00fd kalend\u00e1r (Umm al-Qura)" },
            { "type.ca.ethiopic-amete-alem", "Eti\u00f3psky kalend\u00e1r Amete Alem" },
        };
        return data;
    }
}
